---
# Page settings
layout: documentation-archive
title: Documentation
description: Gulper is a powerful and flexible command-line utility designed for backing up and restoring SQLite, MySQL, and PostgreSQL databases.
keywords: backups, sqlite-backup, mysql-backup, postgresql-backup, s3-backup, clivern

# Hero section
hero:
    title: Documentation
    text: Documentation is here to help you and to make your life easier. We recommend you to take a deep look at every section available, it might save you a lot of time in the future.
---
